Skip to content
View original post on X: Guillermo Rauch
Published
22/100

fx v0.0.15 cuts memory use 70% and speeds up session resumes

AIfx v0.0.15 uses 70% less memory in long sessions and shrinks the binary 7.66%, from 6.66 MiB to 6.15 MiB. Image-heavy turns process up to 3.3 times faster, and session resumes are about 18% faster.
Guillermo RauchVerified on X
@rauchg
View on X

fx is now much faster, smaller and efficient
Try https://fx.sh on your iPhone Duo

Vercel Developers@vercel_dev
fx v0.0.15 Less memory. Faster resumes. Smaller binary. - 70% less memory in long sessions - 7.66% smaller binary (6.15mib ← 6.66mib) - Image-heavy turn processing up to 3.3× faster - Session resumes about 18% faster - Automatic model catalog refresh - Fork conversations with /fork - Better image handling & crash recovery in libfx - Multiple bug fixes & security improvements https://fx.sh/changelog#v0.0.15
View quoted post on X
Source details

Guillermo Rauch · x.comPublished · added here

Original title: fx is now much faster, smaller and efficient